@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0303';
+our $VERSION = '0.0304';
 
 use Moo;
 use strictures 2;
@@ -244,7 +244,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0303
+version 0.0304
 
 =head1 SYNOPSIS
 
@@ -281,8 +281,8 @@ C<Music::ModalFunction> allows querying of a musical database of
 Prolog facts and rules that bind notes, chords, modes, keys and
 diatonic functionality.
 
-* Currently there is a database of facts called C<chord_key/6> and one
-rule named C<pivot_chord_keys/10>.
+A database of facts and rules is constructed. The facts are all called
+C<chord_key> and the rules are C<pivot_chord_keys> and C<roman_key>.
 
 =head1 ATTRIBUTES
 
